@@ -1,8 +1,7 @@
 from typing import Callable, Sequence
-
+from sqlalchemy import Column
 from sqlalchemy.orm.attributes import InstrumentedAttribute
 from sqlalchemy.orm import session
-
 from logic_bank.rule_bank import rule_bank_withdraw  # reduce circular imports
 import logic_bank.rule_bank.rule_bank_setup as rule_bank_setup
 from logic_bank.rule_type.constraint import Constraint
@@ -84,12 +83,12 @@ class Rule:
     """
 
     @staticmethod
-    def sum(derive: InstrumentedAttribute, as_sum_of: any, where: any = None):
+    def sum(derive: InstrumentedAttribute or Column, as_sum_of: any, where: any = None, child_role_name: str = ""):
         """
         Derive parent column as sum of designated child column, optional where
 
         Example
-          Rule.sum(derive=Customer.Balance, as_sum_of=Order.AmountTotal,
+          Rule.sum(derive=models.Customer.Balance, as_sum_of=models.Order.AmountTotal,
                    where=Lambda row: row.ShippedDate is None)
 
         Optimized to eliminate / minimize SQLs: Pruning, Adjustment Logic
@@ -97,19 +96,20 @@ class Rule:
         Args:
             derive: name of parent <class.attribute> being derived
             as_sum_of: name of child <class.attribute> being summed
-            where: optional where clause designated which child rows are summed
+            child_role_name: parent's child accessor attribute (required only for disambiguation)
+            where: optional where clause, designates which child rows are summed
 
 
         """
-        return Sum(derive, as_sum_of, where)
+        return Sum(derive, as_sum_of, where, child_role_name)
 
     @staticmethod
-    def count(derive: InstrumentedAttribute, as_count_of: object, where: any = None):
+    def count(derive: InstrumentedAttribute or Column, as_count_of: object, where: any = None, child_role_name: str = ""):
         """
         Derive parent column as count of designated child rows
 
         Example
-          Rule.count(derive=Customer.UnPaidOrders, as_count_of=Order,
+          Rule.count(derive=models.Customer.UnPaidOrders, as_count_of=models.Order,
                    where=Lambda row: row.ShippedDate is None)
 
         Optimized to eliminate / minimize SQLs: Pruning, Adjustment Logic
@@ -117,9 +117,10 @@ class Rule:
         Args:
             derive: name of parent <class.attribute> being derived
             as_sum_of: name of child <class> being counted
-            where: optional where clause designated which child rows are counted
+            child_role_name: parent's child accessor attribute (required only for disambiguation)
+            where: optional where clause, designates which child rows are counted
         """
-        return Count(derive, as_count_of, where)
+        return Count(derive, as_count_of, where, child_role_name)
 
     @staticmethod
     def constraint(validate: object,
@@ -131,7 +132,7 @@ class Rule:
         Constraints declare condition that must be true for all commits
 
         Example
-          Rule.constraint(validate=Customer,
+          Rule.constraint(validate=models.Customer,
                           as_condition=lambda row: row.Balance <= row.CreditLimit,
                           error_msg="balance ({row.Balance}) exceeds credit ({row.CreditLimit})")
 
@@ -165,7 +166,7 @@ class Rule:
         Parent Checks ensure that non-null foreign keys are present in parent class
 
         Example
-           Rule.parent_check(validate=Customer, enable=True, error_msg="Missing Parent")
+           Rule.parent_check(validate=models.Customer, enable=True, error_msg="Missing Parent")
 
         Parent_check failures raise ConstraintException, e.g.:
             try:
@@ -185,7 +186,7 @@ class Rule:
         return ParentCheck(validate=validate, error_msg=error_msg, enable=enable)
 
     @staticmethod
-    def formula(derive: InstrumentedAttribute,
+    def formula(derive: InstrumentedAttribute or Column,
                 as_exp: str = None,  # string (for very short expression)
                 as_expression: Callable = None,
                 calling: Callable = None,
@@ -194,7 +195,7 @@ class Rule:
         Formulas declare column value, based on current and parent rows
 
         Example
-          Rule.formula(derive=OrderDetail.Amount,
+          Rule.formula(derive=models.OrderDetail.Amount,
                        as_expression=lambda row: row.UnitPrice * row.Quantity)
 
         Unlike Copy rules, Parent changes are propagated to child row(s)
@@ -211,12 +212,12 @@ class Rule:
                        no_prune=no_prune)
 
     @staticmethod
-    def copy(derive: InstrumentedAttribute, from_parent: any):
+    def copy(derive: InstrumentedAttribute or Column, from_parent: any):
         """
         Copy declares child column copied from parent column
 
         Example
-          Rule.copy(derive=OrderDetail.UnitPrice, from_parent=Product.UnitPrice)
+          Rule.copy(derive=models.OrderDetail.UnitPrice, from_parent=models.Product.UnitPrice)
 
         Unlike formulas references, parent changes are *not* propagated to children
 
@@ -323,7 +324,7 @@ class DeclareRule(Rule):
 
         declare_logic():
 
-            DeclareRule.sum(derive=Order.AmountTotal, as_sum_of=OrderDetail.Amount)
+            DeclareRule.sum(derive=models.Order.AmountTotal, as_sum_of=OrderDetail.Amount)
 
     Activate them:
 
